@@ -72,7 +72,8 @@ url_exists <- function(url = "https://www.abs.gov.au") {
 #' 200 range; `FALSE` otherwise.
 #' @noRd
 url_exists_nocurl <- function(url = "https://www.abs.gov.au") {
-  con <- url(url)
+  con <- url(url,
+             Sys.getenv("R_READABS_DL_METHOD", unset = "default"))
   out <- suppressWarnings(tryCatch(readLines(con), error = function(e) e))
   abs_url_works <- all(class(out) != "error")
   close(con)
